==> haskell-data-fix-0.3.4-140.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-fix
version:              0.3.4
visibility:           public
id:                   data-fix-0.3.4-DcHJ3ttKSJw5ofwAk9Vr2A
key:                  data-fix-0.3.4-DcHJ3ttKSJw5ofwAk9Vr2A
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  764270cd6ba3418e092672d46270f04d
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-fix
hs-libraries:         HSdata-fix-0.3.4-DcHJ3ttKSJw5ofwAk9Vr2A
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-fix-0.3.4-142-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-fix
version:              0.3.4
visibility:           public
id:                   data-fix-0.3.4-3won58iaWYcBjetskLCnc9
key:                  data-fix-0.3.4-3won58iaWYcBjetskLCnc9
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  93d09bcac3a88c30a40f996956bcce22
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-fix
hs-libraries:         HSdata-fix-0.3.4-3won58iaWYcBjetskLCnc9
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
